@@ -1,7 +1,7 @@
 # ABSTRACT: take structured address data and format it according to the various global/country rules
 
 package Geo::Address::Formatter;
-$Geo::Address::Formatter::VERSION = '1.65';
+$Geo::Address::Formatter::VERSION = '1.66';
 use strict;
 use warnings;
 use feature qw(say);
@@ -433,6 +433,12 @@ sub _add_code {
                             }
                         }
                     }
+                    if ($rh_components->{state} =~ m/^washington,? d\.?c\.?/i){
+                        $rh_components->{state_code} = 'DC';
+                        $rh_components->{city} = 'Washington';
+                    }
+
+                    
                 }
             }
         }
@@ -628,7 +634,7 @@ Geo::Address::Formatter - take structured address data and format it according t
 
 =head1 VERSION
 
-version 1.65
+version 1.66
 
 =head1 SYNOPSIS
 
